"use client";
import { Button } from "@mui/material";
import { useState, useEffect } from "react";

const ProductMenu = ({ hidden }) => {
  const menuItems = [
    { item: "درباره محصول", sectionId: "about" },
    { item: "نمونه", sectionId: "simple" },
    { item: "مزایا", sectionId: "benefits" },
    { item: "نکات", sectionId: "tips" },
    { item: "نظرات", sectionId: "comments" },
  ];

  // ذخیره سکشن فعال
  const [activeSection, setActiveSection] = useState(null);

  // تابع اسکرول نرم به سکشن مورد نظر
  const scrollToSection = (
    sectionId,
    desktopOffset = 120,
    mobileOffset = 120
  ) => {
    const section = document.getElementById(sectionId);
    if (section) {
      const offset = window.innerWidth <= 768 ? mobileOffset : desktopOffset;
      const sectionTop = section.getBoundingClientRect().top + window.scrollY;
      window.scrollTo({
        top: sectionTop - offset,
        behavior: "smooth",
      });
    } else {
      console.warn(`Section with ID "${sectionId}" not found.`);
    }
  };

  // تشخیص سکشن در حال نمایش و به روزرسانی activeSection
  useEffect(() => {
    const handleScroll = () => {
      let currentSection = null;
      menuItems.forEach((item) => {
        const section = document.getElementById(item.sectionId);
        if (section) {
          const sectionTop = section.getBoundingClientRect().top - 120; // تنظیم فاصله از بالا
          const sectionBottom = section.getBoundingClientRect().bottom - 120;

          // بررسی اینکه اسکرول در محدوده این سکشن قرار دارد
          if (sectionTop <= 100 && sectionBottom >= 100) {
            currentSection = item.sectionId;
          }
        }
      });
      setActiveSection(currentSection);
    };

    window.addEventListener("scroll", handleScroll);
    return () => window.removeEventListener("scroll", handleScroll);
  }, [menuItems]);

  return (
    <div
      className={`w-full h-10 bg-white flex items-center sticky top-[56px] md:top-[65px] z-50 border-b-2 justify-between ${
        hidden && "hidden"
      }`}
    >
      {menuItems.map((item, index) => (
        <Button
          key={index.toString()}
          onClick={() => scrollToSection(item.sectionId)}
          className={`whitespace-nowrap ${
            activeSection === item.sectionId ? "font-bold" : "font-normal"
          }`}
        >
          {item.item}
        </Button>
      ))}
    </div>
  );
};

export default ProductMenu;
